@@ -3,7 +3,7 @@ knitr::opts_chunk$set(warning = FALSE,
                       message = FALSE,
                       collapse = TRUE,
                       comment = "#>",
-                      out.width = "\\textwidth", 
+                      out.width = "100%", 
                       fig.height = 5, 
                       fig.width = 7, 
                       fig.align = "center")
@@ -24,57 +24,61 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  select <- dplyr::select
 
 ## ----st-download--------------------------------------------------------------
-#  # download to a temp directory for the vigette
-#  # in practice, change to permanent directory the status and trends downloads
 #  sp_path <- ebirdst_download(species = "example_data")
 #  # load the abundance data
-#  # this automaticaaly labels layers with their dates
-#  abd <- load_raster("abundance", path = sp_path)
+#  # this automatically labels layers with their dates
+#  abd <- load_raster(sp_path, "abundance")
 
 ## ----ne-data, results="hide"--------------------------------------------------
-#  mollweide <- "+proj=moll +lon_0=-90 +x_0=0 +y_0=0 +ellps=WGS84"
+#  proj <- "+proj=eck4 +lon_0=-90 +x_0=0 +y_0=0 +ellps=WGS84"
 #  ne_scale <- 50
 #  
 #  # land polygon
 #  ne_land <- ne_countries(scale = ne_scale, returnclass = "sf") %>%
 #    filter(continent %in% c("North America", "South America")) %>%
 #    st_set_precision(1e6) %>%
+#    st_make_valid() %>%
 #    st_union() %>%
 #    st_geometry()
 #  # function to subset other features to those  within this land area
 #  wh_subset <- function(x) {
 #    in_wh <- as.logical(st_intersects(x, ne_land, sparse = FALSE))
-#    st_transform(x[in_wh], crs = mollweide)
+#    st_transform(x[in_wh], crs = proj)
 #  }
 #  # country lines
 #  ne_country_lines <- ne_download(scale = ne_scale, category = "cultural",
 #                                  type = "admin_0_boundary_lines_land",
 #                                  returnclass = "sf") %>%
 #    st_geometry() %>%
+#    st_make_valid() %>%
 #    wh_subset()
 #  # state lines
 #  ne_state_lines <- ne_download(scale = ne_scale, category = "cultural",
 #                                type = "admin_1_states_provinces_lines",
 #                                returnclass = "sf") %>%
 #    st_geometry() %>%
+#    st_make_valid() %>%
 #    wh_subset()
 #  # rivers
 #  ne_rivers <- ne_download(scale = ne_scale, category = "physical",
 #                           type = "rivers_lake_centerlines",
 #                           returnclass = "sf") %>%
 #    st_geometry() %>%
+#    st_make_valid() %>%
 #    wh_subset()
 #  # lakes
 #  ne_lakes <- ne_download(scale = ne_scale, category = "physical",
 #                          type = "lakes",
 #                          returnclass = "sf") %>%
 #    st_geometry() %>%
+#    st_make_valid() %>%
 #    wh_subset()
-#  ne_land <- st_transform(ne_land, crs = mollweide)
+#  ne_land <- st_transform(ne_land, crs = proj)
 
 ## ----season-defs--------------------------------------------------------------
 #  # subset to the yellow-bellied sapsucker season definitions
-#  yebsap_dates <- filter(ebirdst_runs, species_code == "yebsap") %>%
+#  run_review <- filter(ebirdst_runs, species_code == "yebsap")
+#  yebsap_dates <- run_review %>%
 #    # just keep the seasonal definition columns
 #    select(setdiff(matches("(start)|(end)"), matches("year_round"))) %>%
 #    # transpose
@@ -82,9 +86,11 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #    # spread data so start and end dates are in separate columns
 #    separate(label, c("season", "start_end"), "_(?=s|e)") %>%
 #    spread(start_end, date) %>%
-#    select(season, start_dt, end_dt)
+#    select(season, start_dt = start, end_dt = end) %>%
+#    filter(season != "resident")
 #  # did the season pass review
-#  yebsap_dates <- mutate(yebsap_dates, pass = !(is.na(start_dt) | is.na(end_dt)))
+#  quality_rating <- run_review[paste0(yebsap_dates$season, "_quality")]
+#  yebsap_dates$pass <- as.integer(quality_rating) > 1
 #  yebsap_dates
 
 ## ----season-assignment--------------------------------------------------------
@@ -134,8 +140,8 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #                     abd_nz[["postbreeding_migration"]],
 #                     maskvalue = 1)
 #    just_post <- mask(abd_nz[["postbreeding_migration"]],
-#                     abd_nz[["prebreeding_migration"]],
-#                     maskvalue = 1)
+#                      abd_nz[["prebreeding_migration"]],
+#                      maskvalue = 1)
 #    # count the number of cells with abundance in only one season
 #    n_just <- cellStats(stack(just_pre, just_post), sum)
 #    n_all <- cellStats(abd_nz, sum)
@@ -167,12 +173,18 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  show_yearround
 
 ## ----breaks-------------------------------------------------------------------
-#  bin_breaks <- calc_bins(abd_season)
+#  vals <- abd_season %>%
+#    getValues() %>%
+#    na.omit() %>%
+#    as.numeric()
+#  bin_breaks <- quantile(vals[vals > 0], seq(0, 1, by = 0.05))
+#  lbls <- signif(bin_breaks[c("5%", "50%", "95%")], 3)
+#  rm(vals)
 
 ## ----abd-map------------------------------------------------------------------
 #  # project the abundance data to mollweide
 #  # use nearest neighbour resampling to preserve true zeros
-#  abd_season_proj <- projectRaster(abd_season, crs = mollweide, method = "ngb")
+#  abd_season_proj <- projectRaster(abd_season, crs = proj, method = "ngb")
 #  # determine spatial extent for plotting
 #  ext <- calc_full_extent(abd_season_proj)
 #  # set the plotting order of the seasons
@@ -185,17 +197,17 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  ne_land_buffer <- st_buffer(ne_land, dist = max(res(pred_region)) / 2)
 #  pred_region <- mask(pred_region, as_Spatial(ne_land_buffer))
 #  
-#  # remove zeros from abundnace layers
+#  # remove zeros from abundance layers
 #  abd_no_zero <- subs(abd_season_proj, data.frame(from = 0, to = NA),
 #                      subsWithNA = FALSE)
 #  
 #  # set up plot area
 #  par(mar = c(0 , 0, 0, 0))
-#  plot(ne_land, col = "#eeeeee", border = NA,
+#  plot(ne_land, col = "#cfcfcf", border = NA,
 #       xlim = c(ext@xmin, ext@xmax),
 #       ylim = c(ext@ymin, ext@ymax))
 #  # prediction region and explicit zeros
-#  plot(pred_region, col = "#dddddd", maxpixels = raster::ncell(pred_region),
+#  plot(pred_region, col = "#e6e6e6", maxpixels = raster::ncell(pred_region),
 #       legend = FALSE, add = TRUE)
 #  # lakes
 #  plot(ne_lakes, col = "#ffffff", border =  "#444444", lwd = 0.5, add = TRUE)
@@ -212,8 +224,8 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #    } else {
 #      pal_season <- s
 #    }
-#    pal <- abundance_palette(length(bin_breaks$bins) - 1, pal_season)
-#    plot(abd_no_zero[[s]], col = pal, breaks = bin_breaks$bins,
+#    pal <- abundance_palette(length(bin_breaks) - 1, pal_season)
+#    plot(abd_no_zero[[s]], col = pal, breaks = bin_breaks,
 #         maxpixels = ncell(abd_no_zero[[s]]),
 #         legend = FALSE, add = TRUE)
 #  }
@@ -233,7 +245,7 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  
 #  # legends
 #  legend_seasons <- plot_seasons
-#  if (split_migration) {
+#  if (!split_migration) {
 #    legend_seasons[legend_seasons %in% c("prebreeding_migration",
 #                                         "postbreeding_migration")] <- "migration"
 #    legend_seasons <- unique(legend_seasons)
@@ -242,31 +254,29 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #    legend_seasons <- c(legend_seasons, "year_round")
 #  }
 #  # thin out labels
-#  lbl_at <- bin_breaks$bins^bin_breaks$power
-#  lbl_at <- c(min(lbl_at), median(lbl_at), max(lbl_at))
-#  lbl <- lbl_at^(1 / bin_breaks$power)
-#  lbl <- format(round(lbl, 2), nsmall = 2)
 #  # plot legends
+#  lbl_at <- seq(0, 1, length.out = length(lbls))
 #  for (i in seq_along(legend_seasons)) {
-#    pal <- abundance_palette(length(bin_breaks$bins) - 1, legend_seasons[i])
+#    pal <- abundance_palette(length(bin_breaks) - 1, legend_seasons[i])
 #    if (i == 1) {
-#      axis_args <- list(at = lbl_at, labels = lbl, line = -1,
+#      axis_args <- list(at = lbl_at, labels = lbls, line = -1,
 #                        cex.axis = 0.75, lwd = 0)
 #    } else {
-#      axis_args <- list(at = lbl_at, labels = rep("", 3),
+#      axis_args <- list(at = lbl_at, labels = rep("", length(lbls)),
 #                        cex.axis = 0.75, lwd = 0)
 #    }
 #    legend_title <- legend_seasons[i] %>%
 #      str_replace_all("_", " ") %>%
 #      str_to_title()
-#    fields::image.plot(zlim = range(bin_breaks$bins^bin_breaks$power),
-#                     legend.only = TRUE,
-#                     breaks = bin_breaks$bins^bin_breaks$power, col = pal,
-#                     smallplot = c(0.05, 0.35, 0.01 + 0.06 * i, 0.03 + 0.06 * i),
-#                     horizontal = TRUE,
-#                     axis.args = axis_args,
-#                     legend.args = list(text = legend_title, side = 3,
-#                                        cex = 0.9, col = "black", line = 0.1))
+#    fields::image.plot(zlim = c(0, 1),
+#                       legend.only = TRUE,
+#                       breaks = seq(0, 1, length.out = length(bin_breaks)),
+#                       col = pal,
+#                       smallplot = c(0.05, 0.35, 0.01 + 0.06 * i, 0.03 + 0.06 * i),
+#                       horizontal = TRUE,
+#                       axis.args = axis_args,
+#                       legend.args = list(text = legend_title, side = 3,
+#                                          cex = 0.9, col = "black", line = 0.1))
 #  }
 #  title("Yellow-bellied Sapsucker Relative Abundance",
 #        line = -1, cex.main = 1)
@@ -333,13 +343,13 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  
 #  # set up plot area
 #  par(mar = c(0 , 0, 0, 0))
-#  plot(ne_land, col = "#eeeeee", border = NA,
+#  plot(ne_land, col = "#cfcfcf", border = NA,
 #       xlim = c(ext@xmin, ext@xmax),
 #       ylim = c(ext@ymin, ext@ymax))
 #  # prediction region and explicit zeros
 #  annual_pred_area <- filter(range_smooth, layer == "prediction_area") %>%
 #    st_union()
-#  plot(annual_pred_area, col = "#dddddd", border = NA, add = TRUE)
+#  plot(annual_pred_area, col = "#e6e6e6", border = NA, add = TRUE)
 #  # lakes
 #  plot(ne_lakes, col = "#ffffff", border =  "#444444", lwd = 0.5, add = TRUE)
 #  # land border
@@ -378,8 +388,8 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  # legend
 #  rng_legend <- rev(range_palette[legend_seasons])
 #  names(rng_legend) <- names(rng_legend) %>%
-#      str_replace_all("_", " ") %>%
-#      str_to_title()
+#    str_replace_all("_", " ") %>%
+#    str_to_title()
 #  legend("bottomleft", legend = names(rng_legend), fill = rng_legend)
 #  title("Yellow-bellied Sapsucker Seasonal Range Map",
 #        line = -1, cex.main = 1)
@@ -394,14 +404,14 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #    filter(county_code != "US.MI.WB")
 
 ## ----aggregate----------------------------------------------------------------
-#  abd_season_agg <- aggregate(abd_season, fact = 3, fun = mean, na.rm = TRUE)
-#  abd_agg <- aggregate(abd, fact = 3, fun = mean, na.rm = TRUE)
+#  abd_season_mr <- load_raster(sp_path, "abundance_seasonal", resolution = "mr")
+#  abd_mr <- load_raster(sp_path, "abundance", resolution = "mr")
 
 ## ----mean-rel-abd-------------------------------------------------------------
-#  abd_mean_region <- raster::extract(abd_season_agg, mi_counties,
+#  abd_mean_region <- raster::extract(abd_season_mr, mi_counties,
 #                                     fun = mean, df = TRUE) %>%
 #    # assign season names
-#    setNames(c("id", names(abd_season_agg))) %>%
+#    setNames(c("id", names(abd_season_mr))) %>%
 #    # attach county attributes
 #    mutate(county_code = mi_counties$county_code) %>%
 #    select(-id)
@@ -415,7 +425,7 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  abd_mean_proj <- abd_mean_region %>%
 #    inner_join(mi_counties, ., by = "county_code") %>%
 #    # transform to mollweide for plotting
-#    st_transform(crs = mollweide)
+#    st_transform(crs = proj)
 #  
 #  # plot
 #  ggplot(abd_mean_proj %>% filter(season %in% c("breeding", "nonbreeding"))) +
@@ -434,7 +444,7 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  
 #  # weekly percent occupied
 #  calc_week_occupied <- function(wk) {
-#    raster::extract(abd_agg[[wk]], mi_counties,
+#    raster::extract(abd_mr[[wk]], mi_counties,
 #                    fun = function(x, ...) {sum(x > 0, na.rm = TRUE) / length(x)},
 #                    df = TRUE) %>%
 #      setNames(c("id", "pct_occupied")) %>%
@@ -445,7 +455,7 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #                pct_occupied = coalesce(pct_occupied, 0))
 #  }
 #  # process weeks independently otherwise we'll run into memory issues
-#  week_occupied <- lapply(seq_len(nlayers(abd_agg)), calc_week_occupied) %>%
+#  week_occupied <- lapply(seq_len(nlayers(abd_mr)), calc_week_occupied) %>%
 #    bind_rows() %>%
 #    mutate(occupied = (pct_occupied > threshold_occupied))
 
@@ -463,7 +473,7 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  days_occ_proj <- days_occupation %>%
 #    inner_join(mi_counties, ., by = "county_code") %>%
 #    # transform to mollweide for plotting
-#    st_transform(crs = mollweide)
+#    st_transform(crs = proj)
 #  
 #  # plot
 #  ggplot(days_occ_proj %>% filter(season %in% c("breeding", "nonbreeding"))) +
